@@ -6,6 +6,10 @@
 
 GHCN::Options - create and manage option lists/objects used by GHCN modules and scripts
 
+=head1 VERSION
+
+version v0.22.258
+
 =head1 SYNOPSIS
 
   use GHCN::Options;
@@ -28,7 +32,7 @@ use Object::Pad 0.66 qw( :experimental(init_expr) );
 package GHCN::Options;
 class   GHCN::Options;
 
-our $VERSION = 'v0.22.257';
+our $VERSION = 'v0.22.258';
 
 use Carp                qw(carp croak);
 use Const::Fast;
@@ -58,12 +62,12 @@ Create a new Options object.
 =cut
 
 ######################################################################
-# Set up the default Tk::Getopt option table first as text, in case
-# an app developer wants to roll their own, and then eval it into an
-# array so it can just be included inside an app %opt definition
+# Set up the default Tk::Getopt option table, which we will use for
+# both Tk::Getopt and to derive an options list of Getopt::Long
+# for when Tk::Getopt is not installed.
 ######################################################################
 
-my $Tk_opt_table_code = <<'__EOT';
+my $Tk_opt_table = [
     'Basic options',
     ['location',     '=s',   undef, label => 'Filter stations by their location name (regex)'],
     ['state',        '=s',   undef, label => 'Filter stations by state or province',
@@ -125,23 +129,9 @@ my $Tk_opt_table_code = <<'__EOT';
     ['color',       '=s',   'red', label => 'Color to use for KML placemarks',
                                    alias => ['colour'] ],
     ['label',       '!',    undef, label => 'Label KML placemarks'],
-__EOT
+];
 
-# Global lexicals
-my $Tk_opt_aref;
-
-# initialize global lexical $Tk_opt_aref
-{
-    # contain this within it's own scope so my variables are destroyed on exit
-    my @opt_list;
-    ## no critic [RequireInterpolationOfMetachars]
-    my $pl = '@opt_list = ( ' . $Tk_opt_table_code . ' );';
-    ## no critic [ProhibitStringyEval]
-    eval $pl or croak;
-    $Tk_opt_aref = \@opt_list;
-}
-
-######################################################################
+    ######################################################################
 # Class fields
 ######################################################################
 
@@ -150,9 +140,6 @@ field $opt_obj      :mutator;   # a Hash::Wrap object derived from $opt_href
 field $config_href  :mutator;   # a hash containing config file options
 field $tk_opt_aref;             # the Tk:Getopt array that defines all GHCN options
 
-# a field containing a copy of the file-scope Tk::Getopt options table source code
-field $tk_opt_code  { $Tk_opt_table_code };
-
 =head1 FIELD ACCESSORS
 
 Writeable (mutator) access is provided for some fields primarily so
@@ -218,7 +205,7 @@ See Tk::Getopt OPTTABLE ARGUMENTS for details.
 =cut
 
 method get_tk_options_table :common () {
-    return wantarray ? ( $Tk_opt_aref->@* ) : $Tk_opt_aref;
+    return wantarray ? ( $Tk_opt_table->@* ) : $Tk_opt_table;
 }
 
 =head2 get_getopt_list
@@ -260,7 +247,7 @@ method get_getopt_list :common () {
     # Further elements are optional too and describe more attributes. For a 
     # complete list of these attributes refer to "OPTTABLE ARGUMENTS".
 
-    foreach my $row ( $Tk_opt_aref->@* ) {
+    foreach my $row ( $Tk_opt_table->@* ) {
         next if ref $row ne 'ARRAY';
 
         # pick off the first three values, then slurp the rest
@@ -321,8 +308,8 @@ of a hash of the valid responses as value/label pairs.
 
 method get_option_choices :common () {
     my %choices;
-    
-    foreach my $row ( $Tk_opt_aref->@* ) {
+
+    foreach my $row ( $Tk_opt_table->@* ) {
         next if ref $row ne 'ARRAY';
 
         # pick off the first three values, then slurp the rest
@@ -330,11 +317,18 @@ method get_option_choices :common () {
         # skip the group dividers
         next if not $opt_kw;
         
-        my %h = @others;
-        
+        my $href;
+        if (@others and ref $others[0] eq 'HASH' ) {
+            $href = $others[0];
+        } elsif (@others % 2 == 0) {
+            $href = { @others };
+        } else {
+            croak "*E* unable to parse opttable: @others";
+        }
+
         my %hv;
-        if ( $h{'choices'} and ref $h{'choices'} eq 'ARRAY' ) {
-            foreach my $aref ( $h{'choices'}->@* ) {
+        if ( $href->{'choices'} and ref $href->{'choices'} eq 'ARRAY' ) {
+            foreach my $aref ( $href->{'choices'}->@* ) {
                 $hv{ $aref->[1] } = $aref->[0];
             }
             $choices{$opt_kw} = \%hv;            
@@ -356,7 +350,7 @@ of lists/strings returned by get_tk_options_table.
 method get_option_defaults :common () {
 
     my %defaults = ();
-    foreach my $slot ($Tk_opt_aref->@*) {
+    foreach my $slot ($Tk_opt_table->@*) {
         next if ref $slot ne 'ARRAY';
         my $key = $slot->[0];
         next if not $key;
@@ -398,7 +392,7 @@ is that a misspelled option name will cause a runtime error.
 
 method combine_options ($user_opt_href) {
     # assign the class-level tk_options_table aref, generated before BUILD, to the instance field
-    $tk_opt_aref = $Tk_opt_aref;
+    $tk_opt_aref = $Tk_opt_table;
 
     my $defaults_href = get_option_defaults();
 
@@ -533,7 +527,7 @@ in the output.
 
 method options_as_string () {
     my @options;
-    my $boolean = _get_boolean_options($Tk_opt_aref);
+    my $boolean = _get_boolean_options($Tk_opt_table);
 
     foreach my $k ( sort keys $opt_href->%* ) {
         my $v = $opt_href->{$k};
@@ -712,4 +706,4 @@ sub _get_boolean_options ($tk_opt_aref) {
 }
 
 
-1;
\ No newline at end of file
+1;
