@@ -6,6 +6,10 @@
 
 GHCN::StationTable - collect station objects and weather data
 
+=head1 VERSION
+
+version v0.22.258
+
 =head1 SYNOPSIS
 
   use GHCN::StationTable;
@@ -61,7 +65,7 @@ use Object::Pad 0.66 qw( :experimental(init_expr) );
 package GHCN::StationTable;
 class   GHCN::StationTable;
 
-our $VERSION = 'v0.22.257';
+our $VERSION = 'v0.22.258';
 
 ## no critic [References::ProhibitDoubleSigils]
 
@@ -460,12 +464,14 @@ method get_hash_stats ( %args ) {
 
     my @output;
 
-    if ( not $args{no_header} ) {
+    my @keys = sort keys %_hstats;
+
+    if ( @keys and not $args{no_header} ) {
         push @output, [ 'Hash sizes:' ];
         push @output, [ qw(Hash Subject Iteration Size) ];
     }
 
-    foreach my $hash ( sort keys %_hstats) {
+    foreach my $hash ( sort @keys ) {
         foreach my $subject ( sort keys $_hstats{$hash}->%* ) {
             foreach my $iter ( sort keys $_hstats{$hash}->{$subject}->%* ) {
                 my $sz = commify( $_hstats{$hash}->{$subject}->{$iter} );
@@ -2639,4 +2645,4 @@ Copyright 2022, Gary Puckering
 
 =cut
 
-1;
\ No newline at end of file
+1;
